import { GolangPluginConfig } from './config';
import { DocumentNode, GraphQLSchema } from 'graphql';
/**
 * GolangGenerator is a class that you instanciate with a GraphQL schema
 * and an optional configuration. You can then call its method `generate`
 * to generate Golang code.
 */
export declare class GolangGenerator {
    /**
     * The configuration used when generating Golang code.
     */
    readonly config: GolangPluginConfig;
    /**
     * The GraphQL schema used to generate Golang code.
     */
    readonly schema: GraphQLSchema;
    private templateEngine;
    private templateOperation;
    /**
     * Map GraphQL type to their Golang format.
     */
    readonly types: {
        [key: string]: string;
    };
    /**
     * Map GraphQL scalar types to Golang types.
     */
    readonly scalars: {
        [key: string]: string;
    };
    private enums;
    private inputs;
    private objects;
    constructor(schema: GraphQLSchema, config?: GolangPluginConfig);
    generate(documents?: DocumentNode[]): string;
    /**
     * Format a name for Golang.
     * @param name Name to format.
     */
    private formatName;
    /**
     * Generate Golang package header.
     */
    private generatePackage;
    /**
     * Generate Golang imports for operations.
     */
    private generateImports;
    /**
     * Generate a named comment section.
     * @param name Name of the section.
     */
    private generateSection;
    /**
     * Generate the Golang types from schema.
     */
    private generateSchema;
    private generateScalars;
    private generateEnums;
    private generateInputs;
    private generateObjects;
    /**
     * Generate a Golang struct's field.
     * @param name Name of the GraphQL field.
     * @param type Type of the GraphQL field.
     */
    private generateField;
    /**
     *
     * @param type TypeNode contains a GraphQL type.
     * @param fieldName GraphQL field's name for the Golang's json annotation.
     * @param prefix String accumulator to add to result when recursion is done.
     * @param nonNull Boolean accumulator to determine if type must be a pointer.
     */
    private generateFieldType;
    /**
     * Generate operations code from a GraphQL document.
     * @param document Document to get the operations from.
     */
    private generateOperations;
    /**
     * Generate Golang `type ${name}Variables struct {...}`.
     * @param name Name of the operation. Must be formatted for Golang.
     * @param variableDefinitions GraphQL variables to generate Golang fields from.
     */
    private generateOperationVariables;
    /**
     * Generates all Golang code for an operation except `type ${name}Variables`
     * and `type ${name}Response`.
     * @param name Name of the operation. Must be formatted for Golang.
     * @param operation String version of the operation.
     * @param hasVariables Whether the operation uses a `${name}Variables` or not.
     */
    private generateOperationCode;
}
